=======
History
=======


0.2.0 (2016-12-23)
------------------

* Basic Auth client for Mautic 2.3
* Improved exception handling


0.1.0 (2016-12-07)
------------------

* Initial port of https://github.com/mautic/api-library/
